import base64
import json
import os

from botocore.exceptions import ClientError

import boto3
from aws_secretsmanager_caching import SecretCache, SecretCacheConfig
import db_paribhasha.db_creds as creds


def get_dbsecret():
    '''
    This function is used to get the value of the database secret from AWS 
    secrets manager and maintains a LRU cache to store the secret
    which gets deleted on every cold start of the container(lambda/docker) 

    RETURNS
    --------
    secret: dict
        Returns the Dict which contains the Db password as one of the key/value
        pairs
    '''
    secret_name = creds.DATABASE_SECRET
    region_name = creds.SECRETS_MANAGER_REGION
    # Create a Secrets Manager client
    session = boto3.session.Session()
    client = session.client(
        service_name='secretsmanager',
        region_name=region_name
    )
    try:
        cache = SecretCache(SecretCacheConfig(),client)
        get_secret_value_response = cache.get_secret_string(secret_name)
    except ClientError as e:
        if e.response['Error']['Code'] == 'DecryptionFailureException':
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'InternalServiceErrorException':
            # An error occurred on the server side.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'InvalidParameterException':
            # You provided an invalid value for a parameter.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'InvalidRequestException':
            # You provided a parameter value that is not valid for the current state of the resource.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
        elif e.response['Error']['Code'] == 'ResourceNotFoundException':
            # We can't find the resource that you asked for.
            # Deal with the exception here, and/or rethrow at your discretion.
            raise e
    else:
        secret = get_secret_value_response
    return secret
