import json

from db_paribhasha.error_handler import DatabaseEntryError
from db_paribhasha.base_models.sql_base_model import session
from db_paribhasha.workflow.users.user_table import User


def get_user(email_id):
    """This function returns the use object when email id
    is given
    Inputs: email id
    Returns: User object
    """
    try:
        user_obj = session.query(User).filter_by(email=email_id).first()
        session.commit()
        if user_obj is None:
            raise DatabaseEntryError("User not present")
    except:
        session.commit()
    return json.dumps(user_obj)
    

def get_user_by_condition(where_condition):
    """
    Function returns the user  which satisfies the condition given as argument.

    Parameters
    -----------
    where_condition: dict
        condition which will be used in where clause in sql query
    
    Returns
    --------
    user_obj: User model
        object of user model
    """
    user_obj = session.query(User).filter_by(**where_condition).first()
    if user_obj is None:
            raise DatabaseEntryError("User not present")
    return user_obj.as_dict()

def has_user(where_condition):
    """
    function he checks whether there the user record exists which satisfies the
    conditions passed as arguments.

    Parameters
    -----------
    where_condition: dict
        condition which will be used in where clause in sql query
    
    Returns
    --------
    bool: 
    True if such user record exists. False, otherwise

    """
    user_obj = session.query(User).filter_by(**where_condition).first()

    return bool(user_obj)
